Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlan Odom <clockmender@icloud.com>2020-01-30 20:34:25 +0300
committerRune Morling <ermo.blender.org@spammesenseless.net>2020-02-01 18:44:02 +0300
commit0e4dd304d6e9a7368cbac785ae4128c426777beb (patch)
tree02b5b08ba772000b444502e3b9022e9d23e3bd43 /precision_drawing_tools/__init__.py
parentff37747efcf9292da7169408f3f8299f37866041 (diff)
PDT: Rename more variables for readability
Diffstat (limited to 'precision_drawing_tools/__init__.py')
-rw-r--r--precision_drawing_tools/__init__.py14
1 files changed, 8 insertions, 6 deletions
diff --git a/precision_drawing_tools/__init__.py b/precision_drawing_tools/__init__.py
index d3639acd..bb0245dc 100644
--- a/precision_drawing_tools/__init__.py
+++ b/precision_drawing_tools/__init__.py
@@ -142,9 +142,9 @@ def enumlist_objects(self, context):
if path.is_file() and ".blend" in str(path):
with bpy.data.libraries.load(str(path)) as (data_from, _):
if len(pg.object_search_string) == 0:
- object_names = [ob for ob in data_from.objects]
+ object_names = [obj for obj in data_from.objects]
else:
- object_names = [ob for ob in data_from.objects if pg.object_search_string in ob]
+ object_names = [obj for obj in data_from.objects if pg.object_search_string in obj]
for object_name in object_names:
_pdt_obj_items.append((object_name, object_name, ""))
else:
@@ -174,10 +174,10 @@ def enumlist_collections(self, context):
if path.is_file() and ".blend" in str(path):
with bpy.data.libraries.load(str(path)) as (data_from, _):
if len(pg.collection_search_string) == 0:
- object_names = [ob for ob in data_from.collections]
+ object_names = [obj for obj in data_from.collections]
else:
object_names = [
ob for ob in data_from.collections if pg.collection_search_string in ob
]
for object_name in object_names:
_pdt_col_items.append((object_name, object_name, ""))
@@ -208,9 +208,11 @@ def enumlist_materials(self, context):
if path.is_file() and ".blend" in str(path):
with bpy.data.libraries.load(str(path)) as (data_from, _):
if len(pg.material_search_string) == 0:
- object_names = [ob for ob in data_from.materials]
+ object_names = [obj for obj in data_from.materials]
else:
- object_names = [ob for ob in data_from.materials if pg.material_search_string in ob]
+ object_names = [
+ obj for obj in data_from.materials if pg.material_search_string in obj
+ ]
for object_name in object_names:
_pdt_mat_items.append((object_name, object_name, ""))
else:
@@ -174,10 +174,10 @@ def enumlist_collections(self, context):
else:
object_names = [
- ob for ob in data_from.collections if pg.collection_search_string in ob
+ obj for obj in data_from.collections if pg.collection_search_string in obj
]
for object_name in object_names: